"""
BeelzeCookie - Cookie Bomb Vulnerability Scanner
A comprehensive tool for detecting cookie bomb vulnerabilities in web applications. I want to be a cookie.
"""

__version__ = "1.0.0"
__author__ = "0xbthn"
__description__ = "Cookie Bomb Vulnerability Scanner" 